@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -23,7 +23,7 @@ import javax.inject.Inject;
 import com.google.gwt.event.dom.client.KeyUpEvent;
 import com.google.gwt.user.client.ui.IsWidget;
 import org.drools.workbench.screens.guided.dtable.client.resources.i18n.GuidedDecisionTableErraiConstants;
-import org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.common.DecisionTableColumnViewUtils;
+import org.drools.workbench.screens.guided.dtable.client.wizard.column.pages.common.DecisionTablePopoverUtils;
 import org.gwtbootstrap3.client.ui.TextBox;
 import org.jboss.errai.common.client.dom.Div;
 import org.jboss.errai.ui.client.local.api.IsElement;
@@ -51,9 +51,6 @@ public class ValueOptionsPageView implements IsElement,
     @DataField("limitedValueGroupContainer")
     private Div limitedValueGroupContainer;
 
-    @DataField("bindingGroupContainer")
-    private Div bindingGroupContainer;
-
     @DataField("valueList")
     private TextBox valueList;
 
@@ -66,46 +63,41 @@ public class ValueOptionsPageView implements IsElement,
     @DataField("limitedValueContainer")
     private Div limitedValueContainer;
 
-    @DataField("bindingContainer")
-    private Div bindingContainer;
-
     private ValueOptionsPage<?> page;
 
     private TranslationService translationService;
 
+    private DecisionTablePopoverUtils popoverUtils;
+
     @Inject
     public ValueOptionsPageView(final Div valueListGroupContainer,
                                 final Div cepWindowOperatorsGroupContainer,
                                 final Div defaultValueGroupContainer,
                                 final Div limitedValueGroupContainer,
-                                final Div bindingGroupContainer,
                                 final TextBox valueList,
                                 final Div cepWindowOperatorsContainer,
                                 final Div defaultValueContainer,
                                 final Div limitedValueContainer,
-                                final Div bindingContainer,
-                                final TranslationService translationService) {
+                                final TranslationService translationService,
+                                final DecisionTablePopoverUtils popoverUtils) {
         this.valueListGroupContainer = valueListGroupContainer;
         this.cepWindowOperatorsGroupContainer = cepWindowOperatorsGroupContainer;
         this.defaultValueGroupContainer = defaultValueGroupContainer;
         this.limitedValueGroupContainer = limitedValueGroupContainer;
-        this.bindingGroupContainer = bindingGroupContainer;
         this.valueList = valueList;
         this.cepWindowOperatorsContainer = cepWindowOperatorsContainer;
         this.defaultValueContainer = defaultValueContainer;
         this.limitedValueContainer = limitedValueContainer;
-        this.bindingContainer = bindingContainer;
         this.translationService = translationService;
+        this.popoverUtils = popoverUtils;
     }
 
     @PostConstruct
     public void initPopovers() {
-        DecisionTableColumnViewUtils.setupPopover(cepWindowOperatorsContainer,
-                                                  translate(GuidedDecisionTableErraiConstants.ValueOptionsPage_CEPWindowDescription));
-        DecisionTableColumnViewUtils.setupPopover(defaultValueContainer,
-                                                  translate(GuidedDecisionTableErraiConstants.ValueOptionsPage_DefaultValueDescription));
-        DecisionTableColumnViewUtils.setupPopover(bindingContainer,
-                                                  translate(GuidedDecisionTableErraiConstants.ValueOptionsPage_BindingDescription));
+        popoverUtils.setupAndRegisterPopover(cepWindowOperatorsContainer,
+                                             translate(GuidedDecisionTableErraiConstants.ValueOptionsPage_CEPWindowDescription));
+        popoverUtils.setupAndRegisterPopover(defaultValueContainer,
+                                             translate(GuidedDecisionTableErraiConstants.ValueOptionsPage_DefaultValueDescription));
     }
 
     @Override
@@ -161,17 +153,6 @@ public class ValueOptionsPageView implements IsElement,
         limitedValueGroupContainer.setHidden(true);
     }
 
-    @Override
-    public void setupBinding(final IsWidget widget) {
-        addWidgetToContainer(widget,
-                             bindingContainer);
-    }
-
-    @Override
-    public void hideBinding() {
-        bindingGroupContainer.setHidden(true);
-    }
-
     @Override
     public void setupCepOperators(final IsWidget widget) {
         addWidgetToContainer(widget,
