@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -30,9 +30,11 @@ import org.mockito.runners.MockitoJUnitRunner;
 import org.uberfire.ext.widgets.core.client.wizards.WizardPageStatusChangeEvent;
 import org.uberfire.mocks.EventSourceMock;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertTrue;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(MockitoJUnitRunner.class)
 public class MetaDataColumnPluginTest {
@@ -80,8 +82,6 @@ public class MetaDataColumnPluginTest {
 
         plugin.setMetaData(metaData);
 
-        when(presenter.isMetaDataUnique(eq(metaData))).thenReturn(true);
-
         final Boolean success = plugin.generateColumn();
 
         verify(presenter).appendColumn(colCaptor.capture());
