@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -41,7 +41,14 @@ import org.uberfire.mocks.CallerMock;
 
 import static org.mockito.Matchers.any;
 import static org.mockito.Matchers.anyString;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 @WithClassesToStub({Select.class, Option.class})
@@ -87,8 +94,8 @@ public class ScenarioWidgetComponentCreatorTest {
         this.ruleNamesServiceCaller = new CallerMock<>(ruleNamesService);
         this.creator = spy(new ScenarioWidgetComponentCreator(ruleNamesServiceCaller));
 
-        when(ruleNamesService.getRuleNames(any(Path.class),
-                                           anyString())).thenReturn(ruleNames);
+        when(ruleNamesService.getRuleNames(any(),
+                                           any())).thenReturn(ruleNames);
         doReturn(button).when(creator).newOkButton();
         doNothing().when(creator).showSelectRuleNameWarning();
         GwtMockito.useProviderForType(HorizontalPanel.class, fakeProvider -> horizontalPanel);
